<?php
/**
 * DBクラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2011 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: photo_mainDb.php 4306 2011-09-09 00:07:15Z fishbone $
 * @link       http://www.magic3.org
 */
require_once($gEnvManager->getDbPath() . '/baseDb.php');

class photo_mainDb extends BaseDb
{
	/**
	 * ブログ定義値を取得をすべて取得
	 *
	 * @param array  $rows			レコード
	 * @return bool					1行以上取得 = true, 取得なし= false
	 */
	function getAllConfig(&$rows)
	{
		$queryStr  = 'SELECT * FROM photo_config ';
		$queryStr .=   'ORDER BY hg_index';
		$retValue = $this->selectRecords($queryStr, array(), $rows);
		return $retValue;
	}
	/**
	 * ブログ定義値を取得
	 *
	 * @param string $key		キーとなる項目値
	 * @return string $value	値
	 */
	function getConfig($key)
	{
		$retValue = '';
		$queryStr = 'SELECT hg_value FROM photo_config ';
		$queryStr .=  'WHERE hg_id  = ?';
		$ret = $this->selectRecord($queryStr, array($key), $row);
		if ($ret) $retValue = $row['hg_value'];
		return $retValue;
	}
	/**
	 * ブログ定義値を更新
	 *
	 * @param string $key		キーとなる項目値
	 * @param string $value		値
	 * @return					true = 正常、false=異常
	 */
	function updateConfig($key, $value)
	{
		// データの確認
		$queryStr = 'SELECT hg_value FROM photo_config ';
		$queryStr .=  'WHERE hg_id  = ?';
		$ret = $this->isRecordExists($queryStr, array($key));
		if ($ret){
			$queryStr = "UPDATE photo_config SET hg_value = ? WHERE hg_id = ?";
			return $this->execStatement($queryStr, array($value, $key));
		} else {
			$queryStr = "INSERT INTO photo_config (hg_id, hg_value) VALUES (?, ?)";
			return $this->execStatement($queryStr, array($key, $value));
		}
	}
	/**
	 * ユーザリスト取得
	 *
	 * @param string   $userOption	検索用ユーザオプション
	 * @param int      $limit		取得する項目数
	 * @param int      $page		取得するページ(1～)
	 * @param function $callback	コールバック関数
	 * @return						なし
	 */
	function getAllUserList($userOption, $limit, $page, $callback)
	{
		$offset = $limit * ($page -1);
		if ($offset < 0) $offset = 0;
		
		$queryStr  = 'SELECT * FROM _login_user LEFT JOIN _login_log on lu_id = ll_user_id ';
		$queryStr .=   'WHERE lu_deleted = false ';// 削除されていない
		$queryStr .=     'AND lu_user_type_option LIKE \'%' . addslashes($userOption) . '%\' ';
		$queryStr .=  'ORDER BY lu_account limit ' . $limit . ' offset ' . $offset;
		$this->selectLoop($queryStr, array(), $callback);
	}
	/**
	 * ユーザ総数取得
	 *
	 * @param string   $userOption	検索用ユーザオプション
	 * @return int					総数
	 */
	function getAllUserListCount($userOption)
	{
		$queryStr  = 'SELECT * FROM _login_user ';
		$queryStr .=   'WHERE lu_deleted = false ';// 削除されていない
		$queryStr .=     'AND lu_user_type_option LIKE \'%' . addslashes($userOption) . '%\' ';
		return $this->selectRecordCount($queryStr, array());
	}
	/**
	 * ユーザ情報をシリアル番号で取得
	 *
	 * @param string	$serial				シリアル番号
	 * @param array     $row				レコード
	 * @return bool							取得 = true, 取得なし= false
	 */
	function getUserBySerial($serial, &$row)
	{
		$queryStr  = 'select * from _login_user ';
		$queryStr .=   'WHERE lu_serial = ? ';
		$ret = $this->selectRecord($queryStr, array($serial), $row);
		return $ret;
	}
	/**
	 * ユーザの削除
	 *
	 * @param array $serial			シリアルNo
	 * @return						true=成功、false=失敗
	 */
	function delUserBySerial($serial)
	{
		// 引数のエラーチェック
		if (!is_array($serial)) return false;
		if (count($serial) <= 0) return true;
		
		$now = date("Y/m/d H:i:s");	// 現在日時
		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
		
		// トランザクション開始
		$this->startTransaction();
		
		// 指定のシリアルNoのレコードが削除状態でないかチェック
		for ($i = 0; $i < count($serial); $i++){
			$queryStr  = 'SELECT * FROM _login_user ';
			$queryStr .=   'WHERE lu_deleted = false ';		// 未削除
			$queryStr .=     'AND lu_serial = ? ';
			$ret = $this->isRecordExists($queryStr, array($serial[$i]));
			// 存在しない場合は、既に削除されたとして終了
			if (!$ret){
				$this->endTransaction();
				return false;
			}
		}
		
		// レコードを削除
		$queryStr  = 'UPDATE _login_user ';
		$queryStr .=   'SET lu_deleted = true, ';	// 削除
		$queryStr .=     'lu_update_user_id = ?, ';
		$queryStr .=     'lu_update_dt = ? ';
		$queryStr .=   'WHERE lu_serial in (' . implode($serial, ',') . ') ';
		$this->execStatement($queryStr, array($userId, $now));
		
		// トランザクション確定
		$ret = $this->endTransaction();
		return $ret;
	}
	/**
	 * 新規の画像Noを取得
	 *
	 * @param int $userId	ユーザID
	 * @return int			画像番号(1～)
	 */
	function getNewPhotoNo($userId)
	{
		// 画像IDを決定する
		$queryStr  = 'SELECT * FROM photo ';
		$queryStr .=   'WHERE ht_owner_id = ? ';
		$queryStr .=     'AND ht_history_index = 0 ';
		return $this->selectRecordCount($queryStr, array($userId), $row) + 1;
	}
	/**
	 * 画像コードが存在するかチェック
	 *
	 * @param string $code	画像コード
	 * @return				true=存在する、false=存在しない
	 */
	function isExistsPhotoCode($code)
	{
		$queryStr  = 'SELECT * FROM photo ';
		$queryStr .=   'WHERE ht_code = ? ';
		return $this->isRecordExists($queryStr, array($code));
	}
	/**
	 * 画像情報の新規追加、更新
	 *
	 * @param bool    $limitedUser	制限ありのユーザかどうか
	 * @param int     $serial		シリアル番号。シリアル番号が0のときは新規追加。
	 * @param strin   $langId		言語ID
	 * @param string  $filename		ファイル名
	 * @param string  $dir			ディレクトリ
	 * @param string  $code			画像コード
	 * @param string  $mimeType		MIMEタイプ
	 * @param string  $imageSize	画像サイズ
	 * @param string  $originalName	元の画像名
	 * @param string  $filesize		ファイルサイズ
	 * @param string  $name			画像名
	 * @param string  $camera		カメラ
	 * @param string  $location		撮影場所
	 * @param timestamp  $date		撮影日
	 * @param string  $note			補足情報
	 * @param string  $license		ライセンス
	 * @param int     $ownerId		所有者ID
	 * @param string  $keyword		検索用キーワード
	 * @param bool    $visible		表示するかどうか
	 * @param int     $newSerial	新規シリアル番号
	 * @return bool					true = 成功、false = 失敗
	 */
	function updatePhotoInfo($limitedUser, $serial, $langId, $filename, $dir, $code, $mimeType, $imageSize, $originalName, $filesize, 
								$name, $camera, $location, $date, $note, $license, $ownerId, $keyword, $visible, &$newSerial)
	{
		$now = date("Y/m/d H:i:s");	// 現在日時
		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
						
		// トランザクション開始
		$this->startTransaction();
		
		// シリアル番号が0のときは新規追加
		if (empty($serial)){
			// 画像コードが存在すればエラー
			if ($this->isExistsPhotoCode($code)){
				$this->endTransaction();
				return false;
			}
			
			// 画像IDを決定する
			$queryStr = 'SELECT MAX(ht_id) AS mid FROM photo ';
			$ret = $this->selectRecord($queryStr, array(), $row);
			if ($ret){
				$photoId = $row['mid'] + 1;
			} else {
				$photoId = 1;
			}
			$historyIndex = 0;
		} else {
			// 指定のシリアルNoのレコードが削除状態でないかチェック
			$historyIndex = 0;		// 履歴番号
			$queryStr  = 'SELECT * FROM photo ';
			$queryStr .=   'WHERE ht_serial = ? ';
			$ret = $this->selectRecord($queryStr, array($serial), $row);
			if ($ret){		// 既に登録レコードがあるとき
				if ($row['ht_deleted']){		// レコードが削除されていれば終了
					$this->endTransaction();
					return false;
				}
				if ($limitedUser && $row['ht_owner_id'] != $ownerId){		// 制限ユーザの場合は所有者が異なるときは更新不可
					$this->endTransaction();
					return false;
				}
				$photoId = $row['ht_id'];
				$langId = $row['ht_language_id'];
				$historyIndex = $row['ht_history_index'] + 1;
			} else {		// 存在しない場合は終了
				$this->endTransaction();
				return false;
			}
			// 古いレコードを削除
			$queryStr  = 'UPDATE photo ';
			$queryStr .=   'SET ht_deleted = true, ';	// 削除
			$queryStr .=     'ht_update_user_id = ?, ';
			$queryStr .=     'ht_update_dt = ? ';
			$queryStr .=   'WHERE ht_serial = ?';
			$this->execStatement($queryStr, array($userId, $now, $serial));
		}
		
		// 新規レコード追加		
		$queryStr  = 'INSERT INTO photo ';
		$queryStr .=   '(ht_id, ';
		$queryStr .=   'ht_language_id, ';
		$queryStr .=   'ht_history_index, ';
		$queryStr .=   'ht_filename, ';
		$queryStr .=   'ht_dir, ';
		$queryStr .=   'ht_code, ';
		$queryStr .=   'ht_mime_type, ';
		$queryStr .=   'ht_image_size, ';
		$queryStr .=   'ht_original_filename, ';
		$queryStr .=   'ht_file_size, ';
		$queryStr .=   'ht_name, ';
		$queryStr .=   'ht_camera, ';
		$queryStr .=   'ht_location, ';
		$queryStr .=   'ht_date, ';
		$queryStr .=   'ht_note, ';
		$queryStr .=   'ht_license, ';
		$queryStr .=   'ht_owner_id, ';
		$queryStr .=   'ht_keyword, ';
		$queryStr .=   'ht_visible, ';		
		$queryStr .=   'ht_create_user_id, ';
		$queryStr .=   'ht_create_dt) ';
		$queryStr .= 'VALUES ';
		$queryStr .=   '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
		$this->execStatement($queryStr, array($photoId, $langId, $historyIndex, $filename, $dir, $code, $mimeType, $imageSize, $originalName, $filesize, 
												$name, $camera, $location, $date, $note, $license, $ownerId, $keyword, intval($visible), $userId, $now));

		// 新規のシリアル番号取得
		$newSerial = 0;
		$queryStr = 'SELECT MAX(ht_serial) AS ns FROM photo ';
		$ret = $this->selectRecord($queryStr, array(), $row);
		if ($ret) $newSerial = $row['ns'];
		
		// トランザクション確定
		$ret = $this->endTransaction();
		return $ret;
	}
	/**
	 * 画像情報を取得
	 *
	 * @param string $filename		ファイル名
	 * @param array $row			取得データ
	 * @return						true=正常、false=異常
	 */
	function getPhotoInfo($filename, &$row)
	{
		$queryStr  = 'SELECT * FROM photo ';
		$queryStr .=   'WHERE ht_deleted = false ';
		$queryStr .=     'AND ht_filename = ? ';
		$ret = $this->selectRecord($queryStr, array($filename), $row);
		return $ret;
	}
	/**
	 * 画像情報を取得
	 *
	 * @param int $serial		シリアル番号
	 * @param array $row		取得データ
	 * @return					true=正常、false=異常
	 */
	function getPhotoInfoBySerial($serial, &$row)
	{
		$queryStr  = 'SELECT * FROM photo ';
		$queryStr .=   'WHERE ht_serial = ? ';
		$ret = $this->selectRecord($queryStr, array($serial), $row);
		return $ret;
	}
	/**
	 * 画像情報の削除
	 *
	 * @param array   $serial		シリアルNo
	 * @return						true=成功、false=失敗
	 */
	function delPhotoInfo($serial)
	{
		// 引数のエラーチェック
		if (!is_array($serial)) return false;
		if (count($serial) <= 0) return true;
		
		$now = date("Y/m/d H:i:s");	// 現在日時
		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
		
		// トランザクション開始
		$this->startTransaction();
		
		for ($i = 0; $i < count($serial); $i++){
			$queryStr  = 'SELECT * FROM photo ';
			$queryStr .=   'WHERE ht_deleted = false ';		// 未削除
			$queryStr .=     'AND ht_serial = ? ';
			$ret = $this->selectRecord($queryStr, array($serial[$i]), $row);
			if ($ret){		// 既に登録レコードがあるとき			
				// レコードを削除
				$queryStr  = 'UPDATE photo ';
				$queryStr .=   'SET ht_deleted = true, ';	// 削除
				$queryStr .=     'ht_update_user_id = ?, ';
				$queryStr .=     'ht_update_dt = ? ';
				$queryStr .=   'WHERE ht_serial = ?';
				$this->execStatement($queryStr, array($userId, $now, $serial[$i]));
			} else {// 指定のシリアルNoのレコードが削除状態のときはエラー
				$this->endTransaction();
				return false;
			}
		}
		// トランザクション確定
		$ret = $this->endTransaction();
		return $ret;
	}
}
?>
